@@ -10,21 +10,22 @@ expect_pass = function(expr) {
 
 test_that("author_df_works", {
 
-  if (have_api_key()) {
+  authorized = is_elsevier_authorized()
+  if (authorized) {
     expect_pass({
       dd = author_df(au_id = "40462056100", all_author_info = TRUE,
                      count = 25)
     })
   }
 
-  if (have_api_key()) {
+  if (authorized) {
     expect_pass({
       dd = author_df(au_id = "40462056100", all_author_info = FALSE,
                      count = 25)
     })
   }
 
-  if (have_api_key()) {
+  if (authorized) {
     expect_pass({
       dd = author_df(au_id = "8858259000", count = 25,
                      all_author_info = FALSE
@@ -32,14 +33,14 @@ test_that("author_df_works", {
     })
   }
 
-  if (have_api_key()) {
+  if (authorized) {
     # testthat::expect_warning({
     expect_warning({
       dd = author_df(au_id = "8858259000", count = 25,
                      general = FALSE)
     })
   }
-  if (have_api_key()) {
+  if (authorized) {
     expect_pass({
       dd = author_list(au_id = "8858259000", count = 25)
     })
